# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['opensr_test']

package_data = \
{'': ['*']}

install_requires = \
['kornia>=0.7.2',
 'matplotlib>=3.7.0',
 'numpy>=1.25.2',
 'opencv-python>=4.8.0.0',
 'pydantic>=2.7.1',
 'requests>=2.25.0',
 'satalign>=0.1.0',
 'scikit-image>=0.19.0',
 'torchvision>=0.17.0']

setup_kwargs = {
    'name': 'opensr-test',
    'version': '0.2.9',
    'description': 'A comprehensive benchmark for real-world Sentinel-2 imagery super-resolution',
    'long_description': '<p align="center">\n  <a href="https://github.com/ESAOpenSR/opensr-test"><img src="docs/images/logo.png" alt="header" width="50%"></a>\n</p>\n\n<p align="center">\n    <em>\n    A comprehensive benchmark for real-world Sentinel-2 imagery super-resolution\n    </em>\n</p>\n\n<p align="center">\n<a href=\'https://pypi.python.org/pypi/opensr-test\'>\n<img src=\'https://img.shields.io/pypi/v/opensr-test.svg\' alt=\'PyPI\' />\n</a>\n<a href="https://opensource.org/licenses/MIT" target="_blank">\n    <img src="https://img.shields.io/badge/License-MIT-blue.svg" alt="License">\n</a>\n<a href="https://github.com/psf/black" target="_blank">\n    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Black">\n</a>\n<a href="https://pycqa.github.io/isort/" target="_blank">\n    <img src="https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336" alt="isort">\n</a>\n</p>\n\n---\n\n**GitHub**: [https://github.com/ESAOpenSR/opensr-test](https://github.com/ESAOpenSR/opensr-test)\n\n**Documentation**: [https://esaopensr.github.io/opensr-test](https://esaopensr.github.io/opensr-test)\n\n**PyPI**: [https://pypi.org/project/opensr-test/](https://pypi.org/project/opensr-test/)\n\n**Paper**: [https://www.techrxiv.org/users/760184/articles/735467-a-comprehensive-benchmark-for-optical-remote-sensing-image-super-resolution](https://www.techrxiv.org/users/760184/articles/735467-a-comprehensive-benchmark-for-optical-remote-sensing-image-super-resolution)\n\n---\n\n#\n\n## **Overview**\n\nSuper-Resolution (SR) aims to improve satellite imagery ground sampling distance. However, two problems are common in the literature. First, most models are **tested on synthetic data**, raising doubts about their real-world applicability and performance. Second, traditional evaluation metrics such as PSNR, LPIPS, and SSIM are not designed to assess SR performance. These metrics fall short, especially in conditions involving changes in luminance or spatial misalignments - scenarios frequently encountered in real world.\n\nTo address these challenges, \'opensr-test\' provides a fair approach for SR benchmark. We provide three datasets carefully crafted to minimize spatial and spectral misalignment. Besides, \'opensr-test\' precisely assesses SR algorithm performance across three independent metrics groups that measure consistency, synthesis, and correctness.\n\n<p align="center">\n  <img src="docs/images/diagram.png" alt="header">\n</p>\n\n## **How to use**\n\nThe example below shows how to use `opensr-test` to benchmark your SR model.\n\n\n```python\nimport torch\nimport opensr_test\n\nlr = torch.rand(4, 64, 64)\nhr = torch.rand(4, 256, 256)\nsr = torch.rand(4, 256, 256)\n\nmetrics = opensr_test.Metrics()\nmetrics.compute(lr=lr, sr=sr, hr=hr)\n>>> {\'reflectance\': 0.253, \'spectral\': 26.967, \'spatial\': 0.0, \'synthesis\': 0.2870, \'ha_percent\': 0.892, \'om_percent\': 0.0613, \'im_percent\': 0.04625}\n```\n\nThis model returns:\n\n- **reflectance**: How SR affects the reflectance values of the LR image. By default, it uses the L1 norm. The lower the value, the better the reflectance consistency.\n\n- **spectral**: How SR affects the spectral signature of the LR image. By default, it uses the spectral angle distance (SAM). The lower the value, the better the spectral consistency. The angles are in degrees.\n\n- **spatial**: The spatial alignment between the SR and LR images. By default, it uses Phase Correlation Coefficient (PCC). Some SR models introduce spatial shift, which can be detected by this metric.\n\n- **synthesis**: The high-frequency details introduced by the SR model. By default, it uses the L1 norm. The lower the value, the better the synthesis quality.\n\n- **ha_percent**: The percentage of pixels in the SR image that are classified as hallucinations. A hallucination is a detail in the SR image that **is not present in the HR image.**\n\n- **om_percent**: The percentage of pixels in the SR image that are classified as omissions. An omission is a detail in the HR image that **is not present in the SR image.**\n\n- **im_percent**: The percentage of pixels in the SR image that are classified as improvements. An improvement is a detail in the SR image that **is present in the HR image and not in the LR image.**\n\n## **Benchmark**\n\nBenchmark comparison of SR models. Downward arrows (↓) denote metrics in which lower values are preferable, and upward arrows (↑) indicate metrics in which higher values reflect better performance.\n\n\n## **Installation**\n\nInstall the latest version from PyPI:\n\n```\npip install opensr-test\n```\n\nUpgrade `opensr-test` by running:\n\n```\npip install -U opensr-test\n```\n\nInstall the latest dev version from GitHub by running:\n\n```\npip install git+https://github.com/ESAOpenSR/opensr-test\n```\n\n## **Datasets**\n\nThe `opensr-test` package provides five datasets for benchmarking SR models. These datasets are carefully crafted to minimize spatial and spectral misalignment. See our Hugging Face repository for more details about the datasets. [**https://huggingface.co/datasets/isp-uv-es/opensr-test**](https://huggingface.co/datasets/isp-uv-es/opensr-test)\n\n### **NAIP (X4 scale factor)**\n\nThe National Agriculture Imagery Program (NAIP) dataset is a high-resolution aerial imagery dataset that covers the continental United States. The dataset consists of 2.5m NAIP imagery captured in the visible and near-infrared spectrum (RGBNIR) and all Sentinel-2 L1C and L2A bands. The dataset focus in **crop fields, forests, and bare soil areas**.\n\n```python\nimport opensr_test\n\nnaip = opensr_test.load("naip")\n```\n\n<p align="center">\n  <a href="https://github.com/ESAOpenSR/opensr-test"><img src="docs/images/NAIP.gif" alt="header" width="80%"></a>\n</p>\n\n### **SPOT (X4 scale factor)**\n\nThe SPOT imagery were obtained from the worldstat dataset. The dataset consists of 2.5m SPOT imagery captured in the visible and near-infrared spectrum (RGBNIR) and all Sentinel-2 L1C and L2A bands. The dataset focus in **urban areas, crop fields, and bare soil areas**.\n\n```python\nimport opensr_test\n\nspot = opensr_test.load("spot")\n```\n\n<p align="center">\n  <a href="https://github.com/ESAOpenSR/opensr-test"><img src="docs/images/SPOT.gif" alt="header" width="80%"></a>\n</p>\n\n\n### **Venµs (X2 scale factor)**\n\nThe Venµs images were obtained from the [**Sen2Venµs dataset**](https://zenodo.org/records/6514159). The dataset consists of 5m Venµs imagery captured in the visible and near-infrared spectrum (RGBNIR) and all Sentinel-2 L1C and L2A bands. The dataset focus in **crop fields, forests, urban areas, and bare soil areas**.\n\n```python\nimport opensr_test\n\nvenus = opensr_test.load("venus")\n```\n\n<p align="center">\n  <a href="https://github.com/ESAOpenSR/opensr-test"><img src="docs/images/VENUS.gif" alt="header" width="80%"></a>\n</p>\n\n\n### **SPAIN CROPS (x4 scale factor)**\n\nThe SPAIN CROPS dataset consists of 2.5m aerial imagery captured in the visible and near-infrared spectrum (RGBNIR) by the Spanish National Geographic Institute (IGN). The dataset includes all Sentinel-2 L1C and L2A bands. The dataset focus in **crop fields and forests**.\n\n```python\nimport opensr_test\n\nspain_crops = opensr_test.load("spain_crops")\n```\n\n<p align="center">\n  <a href="https://github.com/ESAOpenSR/opensr-test"><img src="docs/images/SPAIN_CROPS.gif" alt="header" width="80%"></a>\n</p>\n\n\n### **SPAIN URBAN (x4 scale factor)**\n\nThe SPAIN URBAN dataset consists of 2.5m aerial imagery captured in the visible and near-infrared spectrum (RGBNIR) by the Spanish National Geographic Institute (IGN). The dataset includes all Sentinel-2 L1C and L2A bands. The dataset focus in **urban areas**.\n\n```python\n\nspain_urban = opensr_test.load("spain_urban")\n```\n\n<p align="center">\n  <a href="https://github.com/ESAOpenSR/opensr-test"><img src="docs/images/SPAIN_URBAN.gif" alt="header" width="80%"></a>\n</p>\n\n\n## **Examples**\n\nThe following examples show how to use `opensr-test` to benchmark your SR model.\n\n- Use `opensr-test` with TensorFlow model (SR4RS) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1cAGDGlj5Kqt343inNni3ByLE1856z0gE#scrollTo=xaivkcD5Zfw1&uniqifier=1)\n\n- Use `opensr-test` with PyTorch model (SuperImage) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1Db8-JSMTF-hNZQv2UyBDclxkO5hgP9VR#scrollTo=jVL7o6yOrJkY)\n\n- Use `opensr-test` with a diffuser model (LDMSuperResolutionPipeline) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1banDovG43c2OBh9MODPN4OXgaSCXu1Dc#scrollTo=zz4Aw7_52ulT)\n\n- Use `opensr-test` with a diffuser model (opensr-model) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1banDovG43c2OBh9MODPN4OXgaSCXu1Dc#scrollTo=zz4Aw7_52ulT)\n\n\n- Use `opensr-test` with Pytorch (EvoLand) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1banDovG43c2OBh9MODPN4OXgaSCXu1Dc#scrollTo=zz4Aw7_52ulT)\n\n\n- Use `opensr-test` with Pytorch (SWIN2-MOSE) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1banDovG43c2OBh9MODPN4OXgaSCXu1Dc#scrollTo=zz4Aw7_52ulT)\n\n- Use `opensr-test` with Pytorch (synthetic dataset) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1banDovG43c2OBh9MODPN4OXgaSCXu1Dc#scrollTo=zz4Aw7_52ulT)\n\n## **Visualizations**\n\nThe `opensr-test` package provides a set of visualizations to help you understand the performance of your SR model.\n\n```python\nimport torch\nimport opensr_test\nimport matplotlib.pyplot as plt\n\nfrom super_image import HanModel\n\n# Define the SR model\nsrmodel = HanModel.from_pretrained(\'eugenesiow/han\', scale=4)\n\n# Load the data\nlr, hr, parameters = opensr_test.load("spot").values()\n\n# Define the benchmark experiment\nmetrics = opensr_test.Metrics()\n\n# Define the image to be tested\nidx = 0\nlr_img = torch.from_numpy(lr[idx, 0:3])\nhr_img = torch.from_numpy(hr[idx, 0:3])\nsr_img = srmodel(lr_img[None]).squeeze().detach()\n\n# Compute the metrics\nmetrics.compute(\n    lr=lr_img, sr=sr_img, hr=hr_img,\n    gradient_threshold=parameters[idx]\n)\n```\n\nNow, we can visualize the results using the `opensr_test.visualize` module.\nfDisplay the triplets LR, SR and HR images:\n\n```python\nmetrics.plot_triplets()\n```\n\n<p align="center">\n  <img src="docs/images/example01.png">\n</p>\n\nDisplay a summary of all the metrics:\n\n```python\nmetrics.plot_summary()\n```\n\n<p align="center">\n  <img src="docs/images/example04.png">\n</p>\n\n\nDisplay the correctness of the SR image:\n\n```python\nmetrics.plot_tc()\n```\n\n<p align="center">\n  <img src="docs/images/example05.png">\n</p>\n\n## **Deeper understanding**\n\nExplore the [API](https://esaopensr.github.io/opensr-test/docs/API/config_pydantic.html) section for more details about personalizing your benchmark experiments.\n\n<p align="center">\n    <a href="/docs/api.md"><img src="docs/images/image02.png" alt="opensr-test" width="30%"></a>\n</p>\n\n## **Citation**\n\nIf you use `opensr-test` in your research, please cite our paper:\n\n```\n@article{aybar2024comprehensive,\n  title={A Comprehensive Benchmark for Optical Remote Sensing Image Super-Resolution},\n  author={Aybar, Cesar and Montero, David and Donike, Simon and Kalaitzis, Freddie and G{\\\'o}mez-Chova, Luis},\n  journal={Authorea Preprints},\n  year={2024},\n  publisher={Authorea}\n}\n```\n\n## **Acknowledgements**\n\nThis work was make with the support of the European Space Agency (ESA) under the project “Explainable AI: application to trustworthy super-resolution (OpenSR)”. Cesar Aybar acknowledges support by the National Council of Science, Technology, and Technological Innovation (CONCYTEC, Peru) through the “PROYECTOS DE INVESTIGACIÓN BÁSICA – 2023-01” program with contract number PE501083135-2023-PROCIENCIA. Luis Gómez-Chova acknowledges support from the Spanish Ministry of Science and Innovation (project PID2019-109026RB-I00 funded by MCIN/AEI/10.13039/501100011033).\n',
    'author': 'Cesar Aybar',
    'author_email': 'cesar.aybar@uv.es',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/csaybar/opensr-test',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
